@@ -27,7 +27,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "0.6.0"
+__version__ = "1.0.1"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -47,7 +47,7 @@ from pathlib import Path
 from urllib.parse import urlparse
 
 _LOGGER = logging.getLogger(__title__)
-_SUPPORTED_PIP_STR = ">=9,<=20.2.2"  # Respects requirement in setup.py and latest pip to release date.
+_SUPPORTED_PIP_STR = ">=9,<=20.2.4"  # Respects requirement in setup.py and latest pip to release date.
 
 try:
     from pip import __version__ as pip_version
@@ -327,7 +327,7 @@ def install_pipenv(
                     f.write(index_config_str)
                     f.write(package_entry_str)
 
-                _LOGGER.info("Installing %r", package_entry_str)
+                _LOGGER.info("Installing %r", package_name)
                 called_process = subprocess.run(cmd)
 
                 if called_process.returncode == 0:
